@@ -1,4 +1,4 @@
-from authx.resources.social_messages import get_error_message
+from authx.handler.errors import get_social_error_message
 
 
 class SocialException(Exception):
@@ -11,6 +11,6 @@ class SocialException(Exception):
         cls._base_url = base_url
 
     def __init__(self, msg: str, status_code: int, *args):
-        self.content = get_error_message(msg, self._base_url)
+        self.content = get_social_error_message(msg, self._base_url)
         self.status_code = status_code
         super().__init__(*args)
