@@ -12,6 +12,7 @@ from authx.core.jwt import JWTBackend
 from authx.core.logger import logger
 from authx.core.password import get_password_hash, verify_password
 from authx.core.user import User
+from authx.handler.errors import get_error_message
 from authx.models.user import (
     UserInChangeUsername,
     UserInCreate,
@@ -19,7 +20,6 @@ from authx.models.user import (
     UserInRegister,
     UserPayload,
 )
-from authx.resources.error_messages import get_error_message
 from authx.utils.captcha import validate_captcha
 from authx.utils.strings import create_random_string, hash_string
 
